@@ -40,6 +40,8 @@
 # include "./archs/linux64-s390x/no-asm/include/openssl/opensslconf.h"
 #elif defined(OPENSSL_LINUX) && defined(__s390__)
 # include "./archs/linux32-s390x/no-asm/include/openssl/opensslconf.h"
+#elif defined(OPENSSL_LINUX) && defined(__mips64) && defined(__MIPSEL__)
+# include "./archs/linux64-mips64/no-asm/include/openssl/opensslconf.h"
 #else
 # include "./archs/linux-elf/no-asm/include/openssl/opensslconf.h"
 #endif
